@@ -8,6 +8,24 @@ import json
 import re
 
 
+def get_file_path(repo, select_file):
+    """
+    Retrieve the path of the input file from a GitHub repository.
+    """
+    contents = repo.get_contents("")
+    while contents:
+        file_content = contents.pop(0)
+        if file_content.type == "dir":
+            contents.extend(repo.get_contents(file_content.path))
+        else:
+            file_name = re.sub(r"^.+/", "", file_content.path)
+            if file_name == select_file:
+                return file_content.path
+
+    print(f"File {select_file} not found in the repository.")
+    return None
+
+
 def get_file_list(repo):
     def get_file_names(contents):
         """
